@@ -1,5 +1,5 @@
 /*
- * $Id: cdp_checksum.c,v 1.3 2004/06/07 03:15:56 mchapman Exp $
+ * $Id: cdp_checksum.c,v 1.4 2004/06/09 00:27:04 mchapman Exp $
  */
 
 #include "cdp.h"
@@ -10,15 +10,14 @@
 u_int16_t
 cdp_checksum(const u_int8_t *data, u_int16_t length) {
 	register long sum = 0;
-	u_int16_t *d;
+	register const u_int16_t *d = (const u_int16_t *)data;
 	
-	d = (u_int16_t *)data;
 	while (length > 1) {
 		sum += *d++;
-		length -= sizeof(u_int16_t);
+		length -= 2;
 	}
 	if (length)
-		sum += htons(*d);
+		sum += htons(*(const u_int8_t *)d);
 	
 	sum = (sum >> 16) + (sum & 0xffff);
 	sum += (sum >> 16);
